"""
Tool to download all local datasets and save them within the vega_datasets
source tree.

Usage:
$ python download_datasets.py
"""

import json
from os.path import abspath, join, dirname
import sys
from urllib.request import urlretrieve
import json

sys.path.insert(1, abspath(join(dirname(__file__), "..")))
from vega_datasets.core import Dataset

DATASETS_TO_DOWNLOAD = [
    "airports",
    "anscombe",
    "barley",
    "burtin",
    "cars",
    "crimea",
    "driving",
    "iowa-electricity",
    "iris",
    "la-riots",
    "ohlc",
    "seattle-temps",
    "seattle-weather",
    "sf-temps",
    "stocks",
    "us-employment",
    "wheat",
]


def _download_datasets():
    """Utility to download datasets into package source"""

    def filepath(*args):
        return abspath(join(dirname(__file__), "..", "vega_datasets", *args))

    dataset_listing = {}
    for name in DATASETS_TO_DOWNLOAD:
        data = Dataset(name)
        url = data.url
        filename = filepath("_data", data.filename)
        print("retrieving data {0} -> {1}".format(url, filename))
        urlretrieve(url, filename)
        dataset_listing[name] = "_data/{0}".format(data.filename)
    with open(filepath("local_datasets.json"), "w") as f:
        json.dump(dataset_listing, f, indent=2, sort_keys=True)


if __name__ == "__main__":
    _download_datasets()



"""Tool to re-generate and save vega_datasets/datasets.json

Usage:
$ python generate_datasets_json.py v1.24.0

The second argument is the name of the desired version tag within
http://github.com/vega/vega-datasets/
"""

import json
import os
import subprocess
import sys


def main(tag):
    cwd = os.path.dirname(__file__)
    datasets_src = os.path.join(cwd, "vega-datasets")
    if not os.path.exists(datasets_src):
        print("Cloning vega-datsets...")
        subprocess.check_call(
            ["git", "clone", "http://github.com/vega/vega-datasets.git"], cwd=cwd
        )
    print(f"Checking out '{tag}'")
    subprocess.check_call(["git", "checkout", tag], cwd=datasets_src)

    data_dir = os.path.abspath(os.path.join(datasets_src, "data"))
    datasets_file = os.path.abspath(
        os.path.join(cwd, "..", "vega_datasets", "datasets.json")
    )
    core_file = os.path.abspath(os.path.join(cwd, "..", "vega_datasets", "core.py"))

    print(f"Extracting datasets from {data_dir}")
    datasets = {}
    for filename in os.listdir(data_dir):
        name, fmt = os.path.splitext(filename)
        datasets[name] = {"filename": filename, "format": fmt[1:]}

    print(f"Writing datsets to {datasets_file}")
    with open(datasets_file, "w") as f:
        json.dump(datasets, f, indent=2, sort_keys=True)

    print("Updating SOURCE_TAG in core file")
    subprocess.check_call(
        ["sed", "-i", ".bak", f"s/SOURCE_TAG.*/SOURCE_TAG = {tag!r}/g", core_file]
    )
    subprocess.check_call(["rm", f"{core_file}.bak"])


if __name__ == "__main__":
    if len(sys.argv) == 2:
        main(sys.argv[1])
    else:
        print(__doc__)



import io
import os
import re

from setuptools import setup, find_packages


here = os.path.abspath(os.path.dirname(__file__))


def read(path, encoding="utf-8"):
    path = os.path.join(here, path)
    with io.open(path, encoding=encoding) as fp:
        return fp.read()


def version(path):
    """Obtain the packge version from a python file e.g. pkg/__init__.py
    See <https://packaging.python.org/en/latest/single_source_version.html>.
    """
    version_file = read(path)
    version_match = re.search(
        r"""^__version__ = ['"]([^'"]*)['"]""", version_file, re.M
    )
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


setup(
    name="vega_datasets",
    version=version("vega_datasets/__init__.py"),
    description="A Python package for offline access to Vega datasets",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="Jake VanderPlas",
    author_email="jakevdp@gmail.com",
    maintainer="Jake VanderPlas",
    maintainer_email="jakevdp@gmail.com",
    url="http://github.com/altair-viz/vega_datasets",
    download_url="http://github.com/altair-viz/vega_datasets",
    license="MIT",
    install_requires=["pandas"],
    python_requires=">=3.5",
    tests_require=["pytest"],
    packages=find_packages(exclude=["tools"]),
    package_data={
        "vega_datasets": [
            "datasets.json",
            "dataset_info.json",
            "local_datasets.json",
            os.path.join("_data", "*.json"),
            os.path.join("_data", "*.csv"),
            os.path.join("_data", "*.tsv"),
        ]
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    project_urls={
        "Bug Reports": "https://github.com/altair-viz/vega_datasets/issues",
        "Source": "https://github.com/altair-viz/vega_datasets",
    },
)
